Galera, para quem estiver precisando fiz uma implementação da API PIX em typescript e gostaria de compartilhar com a comunidade. Usando apenas axios e não o SDK:

```
import axios, { Method } from 'axios';
import * as https from 'https';
import * as fs from 'fs';
import * as path from 'path';

export class EfiPayService {
  private readonly certPath: string;
  private readonly clientId: string;
  private readonly clientSecret: string;
  private readonly baseUrl: string;

  constructor() {
    this.certPath = path.resolve(
      __dirname,
      `../../../certs/${process.env.EFI_PAY_CERT}`,
    );
    this.clientId = process.env.EFI_PAY_CLIENT_ID || '';
    this.clientSecret = process.env.EFI_PAY_CLIENT_SECRET || '';
    this.baseUrl = process.env.EFI_PAY_PIX_URL || '';
  }

  private getAgent(): https.Agent {
    const cert = fs.readFileSync(this.certPath);
    return new https.Agent({
      pfx: cert,
      passphrase: '',
    });
  }

  public async getAccessToken(): Promise<string> {
    const agent = this.getAgent();
    const auth = Buffer.from(`${this.clientId}:${this.clientSecret}`).toString(
      'base64',
    );
    const data = JSON.stringify({ grant_type: 'client_credentials' });

    const config = {
      method: 'POST' as Method,
      url: `${this.baseUrl}/oauth/token`,
      headers: {
        Authorization: `Basic ${auth}`,
        'Content-Type': 'application/json',
      },
      httpsAgent: agent,
      data,
    };

    const response = await axios(config);
    return response.data.access_token;
  }

  public async createPixPayment(
    cpf: string,
    full_name: string,
    pixValue: string,
  ): Promise<any> {
    const agent = this.getAgent();
    const accessToken = await this.getAccessToken();
    const endpoint = `${this.baseUrl}/v2/cob`;
    const dataCob = {
      calendario: { expiracao: 900 },
      devedor: { cpf, nome: full_name },
      valor: { original: pixValue },
      chave: "sua-chave-pix",
    };
    const config = {
      method: 'POST' as Method,
      url: endpoint,
      headers: {
        Authorization: `Bearer ${accessToken}`,
        'Content-Type': 'application/json',
      },
      httpsAgent: agent,
      data: dataCob,
    };
    const response = await axios(config);
    return response.data;
  }

  public async generateQrCode(loc: number): Promise<any> {
    const agent = this.getAgent();
    const accessToken = await this.getAccessToken();
    const endpoint = `${this.baseUrl}/v2/loc/${loc}/qrcode`;

    const config = {
      method: 'GET' as Method,
      url: endpoint,
      headers: {
        Authorization: `Bearer ${accessToken}`,
        'Content-Type': 'application/json',
      },
      httpsAgent: agent,
    };

    const response = await axios(config);
    return response.data;
  }

  public async verifyPixPayment(paymentId: string): Promise<any> {
    const agent = this.getAgent();

    const accessToken = await this.getAccessToken();

    const endpoint = `${this.baseUrl}/v2/cob/${paymentId}`;

    const config = {
      method: 'GET' as Method,
      url: endpoint,
      headers: {
        Authorization: `Bearer ${accessToken}`,
        'Content-Type': 'application/json',

      },
      httpsAgent: agent,
    };

    const response = await axios(config);
    return response.data;
  }
}
```